/************************************************************************
**************************************************************************
**                                                                      **
**  JayCalc.h                                                           **
**  ---------                                                           **
**                                                                      **
**  Auteur : Eric Le Saux                                               **
**                                                                      **
**           Club Amiga Montreal (CAM)                                  **
**           C.P. 195 STATION "N"                                       **
**           Montreal (Quebec)                                          **
**           H2X 3M2, CANADA                                            **
**                                                                      **
**  Date   : 20 decembre 1987                                           **
**                                                                      **
**  Statut : DOMAINE PUBLIC - Distribution non-commerciale seulement    **
**           PUBLIC DOMAIN  - Freely redistributable                    **
**                                                                      **
**************************************************************************
 ************************************************************************/

/*=== ID du gadget de changement de mode. ===*/

#define Mode_ID		'M'

/*=== ID des touches de la calculatrice. ===*/

#define KeyA_ID		'A'
#define KeyNA_ID	'a'
#define KeyB_ID		'B'
#define KeyNB_ID	'b'
#define KeyC_ID		'C'
#define KeyNC_ID	'c'
#define KeyOR_ID	'|'
#define KeyEqu_ID	'='
#define KeyRst_ID	'R'

#define ParOuv_ID	'('
#define ParFer_ID	')'
#define Back_ID		'D'
#define ScrolD_ID	'>'
#define ScrolG_ID	'<'

/*=== ID des string gadgets. ===*/

#define EquGadg_ID	'E'
#define LFGadg_ID	'L'

/*=== ID ordonnes des gadgets du diagramme de Venn. ===*/

#define Venn0_ID	 0
#define VennC_ID	 1
#define VennB_ID	 2
#define VennBC_ID	 3
#define VennA_ID	 4
#define VennAC_ID	 5
#define VennAB_ID	 6
#define VennABC_ID	 7

/*=== Titres: definitions pour ceux qui ne sont utilises qu'une fois. ===*/

#define TITRE      " JayCalc "
#define LFGADGDEF  "v1.0"
#define EQUGADGDEF "par Eric Le Saux"

UBYTE *NOP_STRING = (UBYTE *)"NIL";

/*=== Nb de caracteres affichables dans le gadget de l'equation. ===*/

#define NBEQUAFF	21

/*************************************************************************
**************************************************************************
**
**  Les Gadgets du diagramme de Venn
**
**  L'ordre dans lequel ils sont lies EST important : il correspond a
**  la position des bits du minterm.
**  ( C -> B -> BC -> A -> AC -> AB -> ABC )
**
**  A chaque gadget correspond un masque.  Il correspond a la region
**  sensible du gadget.  C'est aussi avec ce masque que le gadget
**  est complemente lorsqu'il est selectionne.
**
*/

UWORD MasqueABCData[28] =
{
   0x0000,0x0000,
   0x0000,0x0000,
   0x003C,0x0000,
   0x00FF,0x0000,
   0x03FF,0xC000,
   0x07FF,0xE000,
   0x0FFF,0xF000,
   0x1FFF,0xF800,
   0x3FFF,0xFC00,
   0x3FFF,0xFC00,
   0x07FF,0xC000,
   0x0000,0x0000,
   0x0000,0x0000,
   0x0000,0x0000
};

struct BoolInfo VennABCBool =
{
	BOOLMASK,
	MasqueABCData,
	0L
};

struct BitMap VennABCBitMap =
{
	4,			/* Nb de bytes par rangee */
	14,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueABCData,(PLANEPTR)MasqueABCData}/* Bitplanes */
};

struct Gadget VennABCGadg =
{
	NULL,			/* Gadget suivant */
	43,28,			/* Coin superieur gauche (x,y) */
	23,14,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennABCBool,	/* structure SpecialInfo */
	VennABC_ID,		/* Identification du gadget */
	(APTR)&VennABCBitMap	/* User data : MasqueBitMap */
};


UWORD MasqueABData[24] =
{
   0x0000,0x0000,
   0x00FF,0xF800,
   0x0FFF,0xFFE0,
   0x0FFF,0xFFE0,
   0x07FF,0xFF80,
   0x03FF,0xFE00,
   0x01FF,0xFC00,
   0x00FF,0xF800,
   0x003F,0xF000,
   0x000F,0xE000,
   0x0003,0xC000,
   0x0000,0x0000
};

struct BoolInfo VennABBool =
{
	BOOLMASK,
	MasqueABData,
	0L
};

struct BitMap VennABBitMap =
{
	4,			/* Nb de bytes par rangee */
	12,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueABData,(PLANEPTR)MasqueABData}/* Bitplanes */
};

struct Gadget VennABGadg =
{
	&VennABCGadg,		/* Gadget suivant */
	24, 26,			/* Coin superieur gauche (x,y) */
	29, 12,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennABBool,	/* structure SpecialInfo */
	VennAB_ID,		/* Identification du gadget */
	(APTR)&VennABBitMap	/* User data : MasqueBitMap */
};


UWORD MasqueACData[26] =
{
   0x0000,0x0000,
   0x0000,0x0000,
   0x007F,0xFC00,
   0x1FFF,0xFF80,
   0x1FFF,0xFF80,
   0x07FF,0xFF00,
   0x01FF,0xFE00,
   0x00FF,0xFC00,
   0x007F,0xF800,
   0x003F,0xE000,
   0x001F,0x8000,
   0x000E,0x0000,
   0x0000,0x0000
};

struct BoolInfo VennACBool =
{
	BOOLMASK,
	MasqueACData,
	0L
};

struct BitMap VennACBitMap =
{
	4,			/* Nb de bytes par rangee */
	13,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueACData,(PLANEPTR)MasqueACData}/* Bitplanes */
};

struct Gadget VennACGadg =
{
	&VennABGadg,		/* Gadget suivant */
	56,25,			/* Coin superieur gauche (x,y) */
	27,13,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennACBool,	/* structure SpecialInfo */
	VennAC_ID,		/* Identification du gadget */
	(APTR)&VennACBitMap	/* User data : MasqueBitMap */
};


UWORD MasqueAData[80] =
{
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x00FF,0xF800,0x0000,
   0x0000,0x3FFF,0xFFE0,0x0000,
   0x0003,0xFFFC,0xFFFE,0x0000,
   0x000F,0xFFF8,0x7FFF,0x8000,
   0x003F,0xFFF8,0x7FFF,0xE000,
   0x00FF,0xFFF3,0x3FFF,0xF800,
   0x01FF,0xFFF0,0x3FFF,0xFC00,
   0x03FF,0xFFE7,0x9FFF,0xFE00,
   0x07FF,0xFFE7,0x9FFF,0xFF00,
   0x0FFF,0xFFFF,0xFFFF,0xFF80,
   0x0C00,0x01FF,0xFE00,0x0080,
   0x0000,0x0007,0x8000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,0x0000
};

struct BoolInfo VennABool =
{
	BOOLMASK,
	MasqueAData,
	0L
};

struct BitMap VennABitMap =
{
	8,			/* Nb de bytes par rangee */
	20,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueAData,(PLANEPTR)MasqueAData}	/* Bitplanes */
};

struct Gadget VennAGadg =
{
	&VennACGadg,		/* Gadget suivant */
	24,12,			/* Coin superieur gauche (x,y) */
	62,20,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennABool,	/* structure SpecialInfo */
	VennA_ID,		/* Identification du gadget */
	(APTR)&VennABitMap	/* User data : MasqueBitMap */
};


UWORD MasqueBCData[22] =
{
   0x0000,0x0000,
   0x0000,0x0000,
   0x1000,0x0600,
   0x1FFF,0xFE00,
   0x0FFF,0xFC00,
   0x07FF,0xF800,
   0x03FF,0xF000,
   0x01FF,0xE000,
   0x007F,0x8000,
   0x001E,0x0000,
   0x0000,0x0000
};

struct BoolInfo VennBCBool =
{
	BOOLMASK,
	MasqueBCData,
	0L
};

struct BitMap VennBCBitMap =
{
	4,			/* Nb de bytes par rangee */
	11,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueBCData,(PLANEPTR)MasqueBCData}/* Bitplanes */
};

struct Gadget VennBCGadg =
{
	&VennAGadg,		/* Gadget suivant */
	42,37,			/* Coin superieur gauche (x,y) */
	24,11,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennBCBool,	/* structure SpecialInfo */
	VennBC_ID,		/* Identification du gadget */
	(APTR)&VennBCBitMap	/* User data : MasqueBitMap */
};


UWORD MasqueBData[81] =
{
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,
   0x0007,0x0000,0x0000,
   0x001F,0x8000,0x0000,
   0x007F,0xC000,0x0000,
   0x01FF,0xE000,0x0000,
   0x03FF,0xF000,0x0000,
   0x07FF,0xF800,0x0000,
   0x0FFF,0xFE00,0x0000,
   0x1FFF,0xFF80,0x0000,
   0x1FFF,0xFFE0,0x0000,
   0x1FFC,0x0FFE,0x0000,
   0x1FFE,0x67FF,0x8000,
   0x1FFE,0x67FF,0x8000,
   0x0FFE,0x0FFF,0xC000,
   0x07FE,0x67FF,0xE000,
   0x03FE,0x67FF,0xF000,
   0x01FC,0x0FFF,0xF800,
   0x007F,0xFFFF,0xFC00,
   0x001F,0xFFFF,0xFF00,
   0x0007,0xFFFF,0xFFC0,
   0x0000,0x7FFF,0xFFC0,
   0x0000,0x01FF,0xF000,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000
};

struct BoolInfo VennBBool =
{
	BOOLMASK,
	MasqueBData,
	0L
};

struct BitMap VennBBitMap =
{
	6,			/* Nb de bytes par rangee */
	26,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueBData,(PLANEPTR)MasqueBData}	/* Bitplanes */
};

struct Gadget VennBGadg =
{
	&VennBCGadg,		/* Gadget suivant */
	9,27,			/* Coin superieur gauche (x,y) */
	45,26,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,		/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennBBool,	/* structure SpecialInfo */
	VennB_ID,		/* Identification du gadget */
	(APTR)&VennBBitMap	/* User data : MasqueBitMap */
};


UWORD MasqueCData[78] =
{
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,
   0x0000,0x0007,0x8000,
   0x0000,0x000F,0xE000,
   0x0000,0x001F,0xF800,
   0x0000,0x003F,0xFE00,
   0x0000,0x007F,0xFF00,
   0x0000,0x00FF,0xFF80,
   0x0000,0x03FF,0xFFC0,
   0x0000,0x0FFF,0xFFE0,
   0x0000,0x3FFF,0xFFE0,
   0x0003,0xFFC3,0xFFE0,
   0x0007,0xFF99,0xFFE0,
   0x0007,0xFF3F,0xFFE0,
   0x000F,0xFF3F,0xFFC0,
   0x001F,0xFF3F,0xFF80,
   0x003F,0xFF99,0xFF00,
   0x007F,0xFFC3,0xFE00,
   0x00FF,0xFFFF,0xF800,
   0x03FF,0xFFFF,0xE000,
   0x0FFF,0xFFFF,0x8000,
   0x0FFF,0xFFF8,0x0000,
   0x003F,0xFE00,0x0000,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0000
};

struct BoolInfo VennCBool =
{
	BOOLMASK,
	MasqueCData,
	0L
};

struct BitMap VennCBitMap =
{
	6,			/* Nb de bytes par rangee */
	26,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)MasqueCData,(PLANEPTR)MasqueCData}	/* Bitplanes */
};

struct Gadget VennCGadg =
{
	&VennBGadg,		/* Gadget suivant */
	55,27,			/* Coin superieur gauche (x,y) */
	46,26,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&VennCBool,	/* structure SpecialInfo */
	VennC_ID,		/* Identification du gadget */
	(APTR)&VennCBitMap	/* User data : MasqueBitMap */
};


UWORD Masque0Data[294] =
{
   0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFFF0,0x0007,0xFFFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFC00,0x0000,0x1FFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xC000,0x0000,0x01FF,0xFFFF,0xFC00,
   0xFFFF,0xFFFE,0x0000,0x0000,0x007F,0xFFFF,0xFC00,
   0xFFFF,0xFFF8,0x0000,0x0000,0x001F,0xFFFF,0xFC00,
   0xFFFF,0xFFE0,0x0000,0x0000,0x0007,0xFFFF,0xFC00,
   0xFFFF,0xFF80,0x0000,0x0000,0x0003,0xFFFF,0xFC00,
   0xFFFF,0xFF00,0x0000,0x0000,0x0001,0xFFFF,0xFC00,
   0xFFFF,0xFE00,0x0000,0x0000,0x0000,0xFFFF,0xFC00,
   0xFFFF,0xFC00,0x0000,0x0000,0x0000,0x7FFF,0xFC00,
   0xFFFF,0xF800,0x0000,0x0000,0x0000,0x3FFF,0xFC00,
   0xFFFF,0xF000,0x0000,0x0000,0x0000,0x3FFF,0xFC00,
   0xFFFF,0xF000,0x0000,0x0000,0x0000,0x0FFF,0xFC00,
   0xFFFF,0xC000,0x0000,0x0000,0x0000,0x00FF,0xFC00,
   0xFFFE,0x0000,0x0000,0x0000,0x0000,0x003F,0xFC00,
   0xFFF8,0x0000,0x0000,0x0000,0x0000,0x000F,0xFC00,
   0xFFE0,0x0000,0x0000,0x0000,0x0000,0x0003,0xFC00,
   0xFF80,0x0000,0x0000,0x0000,0x0000,0x0001,0xFC00,
   0xFF00,0x0000,0x0000,0x0000,0x0000,0x0000,0xFC00,
   0xFE00,0x0000,0x0000,0x0000,0x0000,0x0000,0x7C00,
   0xFC00,0x0000,0x0000,0x0000,0x0000,0x0000,0x3C00,
   0xF800,0x0000,0x0000,0x0000,0x0000,0x0000,0x1C00,
   0xF000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1C00,
   0xF000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1C00,
   0xF000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1C00,
   0xF000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1C00,
   0xF000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3C00,
   0xF800,0x0000,0x0000,0x0000,0x0000,0x0000,0x7C00,
   0xFC00,0x0000,0x0000,0x0000,0x0000,0x0000,0xFC00,
   0xFE00,0x0000,0x0000,0x0000,0x0000,0x0001,0xFC00,
   0xFF00,0x0000,0x0000,0x0000,0x0000,0x0003,0xFC00,
   0xFF80,0x0000,0x0000,0x0000,0x0000,0x000F,0xFC00,
   0xFFE0,0x0000,0x0000,0x0000,0x0000,0x003F,0xFC00,
   0xFFF8,0x0000,0x0000,0x0000,0x0000,0x00FF,0xFC00,
   0xFFFE,0x0000,0x0000,0x0000,0x0000,0x07FF,0xFC00,
   0xFFFF,0xE000,0x0000,0xF000,0x0000,0x7FFF,0xFC00,
   0xFFFF,0xFF80,0x003F,0xFFC0,0x001F,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFC00,
   0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFC00
};

struct BoolInfo Venn0Bool =
{
	BOOLMASK,
	Masque0Data,
	0L
};

struct BitMap Venn0BitMap =
{
	14,			/* Nb de bytes par rangee */
	42,			/* Nb de rangees */
	0,			/* Flags */
	2,			/* Nb de bitplanes */
	0,			/* Pad */
	{(PLANEPTR)Masque0Data,(PLANEPTR)Masque0Data}	/* Bitplanes */
};

struct Gadget Venn0Gadg =
{
	&VennCGadg,		/* Gadget suivant */
	2,12,			/* Coin superieur gauche (x,y) */
	102,42,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|TOGGLESELECT|BOOLEXTEND,		/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&Venn0Bool,	/* structure SpecialInfo */
	Venn0_ID,		/* Identification du gadget */
	(APTR)&Venn0BitMap	/* User data : MasqueBitMap */
};


/*=== Tete de liste ===*/

#define VennGadgList Venn0Gadg

/*************************************************************************
**************************************************************************
**
**  Les String Gadgets.
**
**  Ils n'ont pas de cadre reel.  Il en ont un virtuellement avec
**  le dessin de la calculatrice.
**
*/

#define MAX(a,b) ((a)>(b)?(a):(b))

#define EQUBUFFLEN 41
#define LFBUFFLEN   8

UBYTE UndoBuffer[MAX(EQUBUFFLEN,LFBUFFLEN)];


UBYTE LFGadgSIBuff[LFBUFFLEN] = LFGADGDEF;

struct StringInfo LFGadgSInfo =
{
	LFGadgSIBuff,		/* Buffer pour contenir le texte */
	UndoBuffer,		/* Buffer pour les abandons (Amiga-Q) */
	0,			/* Position du curseur dans le buffer (0..n) */
	LFBUFFLEN,		/* Nb max de characteres dans le buffer */
	0,			/* Position du premier caractere affiche */
	0,0,0,0,0,		/* Initialisees et maintenues par Intuition */
	0,			/* RastPort du gadget */
	0,			/* Pour les gadgets numeriques */
	NULL			/* On veut la keymap par defaut */
};

struct Gadget LFGadg =
{
	&VennGadgList,		/* Gadget suivant */
	204,41,			/* Coin superieur gauche (x,y) */
	57,9,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	RELVERIFY|STRINGCENTER,	/* Flags d'activation */
	STRGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&LFGadgSInfo,	/* structure SpecialInfo */
	LFGadg_ID,		/* Identification du gadget */
	NULL			/* User data */
};

UBYTE EquGadgSIBuff[EQUBUFFLEN] = EQUGADGDEF;

struct StringInfo EquGadgSInfo =
{
	EquGadgSIBuff,		/* Buffer pour contenir le texte */
	UndoBuffer,		/* Buffer pour les abandons (Amiga-Q) */
	0,			/* Position du curseur dans le buffer (0..n) */
	EQUBUFFLEN,		/* Nb max de characteres dans le buffer */
	0,			/* Position du premier caractere affiche */
	0,0,0,0,0,		/* Initialisees et maintenues par Intuition */
	0,			/* RastPort du gadget */
	0,			/* Pour les gadgets numeriques */
	NULL			/* On veut la keymap par defaut */
};

struct Gadget EquGadg =
{
	&LFGadg,		/* Gadget suivant */
	133,21,			/* Coin superieur gauche (x,y) */
	164,9,			/* Largeur et hauteur */
	GADGHCOMP,		/* Flags */
	GADGIMMEDIATE|RELVERIFY|STRINGCENTER,	/* Flags d'activation */
	STRGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	(APTR)&EquGadgSInfo,	/* structure SpecialInfo */
	EquGadg_ID,		/* Identification du gadget */
	NULL			/* User data */
};

/*=== Tete de liste des string gadgets ===*/

#define StringGadgList EquGadg

/*************************************************************************
**************************************************************************
**
**  Les Gadgets du Keypad.
**
**  Pas de cadres reels eux non plus, pour les memes raisons que les
**  string gadgets.
**
*/


struct Gadget ScrollDroite =
{
	&StringGadgList,	/* Gadget suivant */
	385,39,			/* Coin superieur gauche (x,y) */
	12,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	ScrolD_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget ScrollGauche =
{
	&ScrollDroite,		/* Gadget suivant */
	371,39,			/* Coin superieur gauche (x,y) */
	12,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	ScrolG_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget Backspace =
{
	&ScrollGauche,		/* Gadget suivant */
	371,27,			/* Coin superieur gauche (x,y) */
	26,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	Back_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget ParFerGadg =
{
	&Backspace,		/* Gadget suivant */
	385,15,			/* Coin superieur gauche (x,y) */
	12,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	ParFer_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget ParOuvGadg =
{
	&ParFerGadg,		/* Gadget suivant */
	371,15,			/* Coin superieur gauche (x,y) */
	12,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	ParOuv_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyRstGadg =
{
	&ParOuvGadg,		/* Gadget suivant */
	351,39,			/* Coin superieur gauche (x,y) */
	18,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyRst_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyEquGadg =
{
	&KeyRstGadg,		/* Gadget suivant */
	351,15,			/* Coin superieur gauche (x,y) */
	18,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyEqu_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyORGadg =
{
	&KeyEquGadg,		/* Gadget suivant */
	351,27,			/* Coin superieur gauche (x,y) */
	18,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyOR_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyNCGadg =
{
	&KeyORGadg,		/* Gadget suivant */
	333,39,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyNC_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyCGadg =
{
	&KeyNCGadg,		/* Gadget suivant */
	315,39,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyC_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyNBGadg =
{
	&KeyCGadg,		/* Gadget suivant */
	333,27,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyNB_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyBGadg =
{
	&KeyNBGadg,		/* Gadget suivant */
	315,27,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyB_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyNAGadg =
{
	&KeyBGadg,		/* Gadget suivant */
	333,15,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyNA_ID,		/* Identification du gadget */
	NULL			/* User data */
};

struct Gadget KeyAGadg =
{
	&KeyNAGadg,		/* Gadget suivant */
	315,15,			/* Coin superieur gauche (x,y) */
	16,11,			/* Largeur et hauteur */
	NULL,			/* Flags */
	RELVERIFY|GADGHCOMP,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	NULL,			/* Ptr a une image ou bordure */
	NULL,			/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	KeyA_ID,		/* Identification du gadget */
	NULL			/* User data */
};

/*=== Tete de liste des gadgets du Keypad ===*/

#define KeyGadgList KeyAGadg

/*************************************************************************
**************************************************************************
**
**  Le Gadget pour les Changements de Mode.
**
*/


UWORD DECData[] =
{
   0x4000,0x0000,0x0000,
   0x07FF,0xFFFF,0xFC00,
   0x07E0,0x3FFF,0xFC00,
   0x07E7,0x3FFF,0xFC00,
   0x0783,0x0000,0x7C00,
   0x071B,0x1E1E,0x3C00,
   0x0737,0x3333,0x3C00,
   0x0733,0x3F30,0x3C00,
   0x0733,0x3033,0x3C00,
   0x071D,0x9E1E,0x3C00,
   0x0780,0x0000,0x7C00,
   0x07FF,0xFFFF,0xFC00,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0200,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFF8,0xFFFF,0xFF00,
   0xFFFC,0xFFFF,0xFF00,
   0xFFE4,0xE1E1,0xFF00,
   0xFFC8,0xCCCC,0xFF00,
   0xFFCC,0xC0CF,0xFF00,
   0xFFCC,0xCFCC,0xFF00,
   0xFFE2,0x61E1,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00
};

struct Image DECImage =
{
	0,0,			/* Decalage XY du coin superieur gauche du contenant */
	40,14,			/* Largeur et hauteur */
	2,			/* Nb de bitplanes */
	DECData,		/* Ptr a l'information graphique */
	0x0003,0x0000,		/* PlanePick et PlaneOnOff */
	NULL			/* Structure Image suivante */
};

UWORD HEXData[] =
{
   0x4000,0x0000,0x0000,
   0x07FF,0xFFFF,0xFC00,
   0x0603,0xFFFF,0xFC00,
   0x0673,0xFFFF,0xFC00,
   0x0630,0x0000,0x1C00,
   0x0736,0x1E31,0x9C00,
   0x073B,0x331B,0x1C00,
   0x0733,0x3F0E,0x3C00,
   0x0633,0x301B,0x1C00,
   0x0673,0x1E31,0x9C00,
   0x0600,0x0000,0x1C00,
   0x07FF,0xFFFF,0xFC00,
   0x0000,0x0000,0x0000,
   0x0000,0x0000,0x0200,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFF8F,0xFFFF,0xFF00,
   0xFFCF,0xFFFF,0xFF00,
   0xFFC9,0xE1CE,0x7F00,
   0xFFC4,0xCCE4,0xFF00,
   0xFFCC,0xC0F1,0xFF00,
   0xFFCC,0xCFE4,0xFF00,
   0xFF8C,0xE1CE,0x7F00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00,
   0xFFFF,0xFFFF,0xFF00
};

struct Image HEXImage =
{
	0,0,			/* Decalage XY du coin superieur gauche du contenant */
	40,14,			/* Largeur et hauteur */
	2,			/* Nb de bitplanes */
	HEXData,		/* Ptr a l'information graphique */
	0x0003,0x0000,		/* PlanePick et PlaneOnOff */
	NULL			/* Structure Image suivante */
};

struct Gadget ModeGadg =
{
	&KeyGadgList,		/* Gadget suivant */
	267,38,			/* Coin superieur gauche (x,y) */
	40,14,			/* Largeur et hauteur */
	GADGHIMAGE|GADGIMAGE,	/* Flags */
	GADGIMMEDIATE|TOGGLESELECT,	/* Flags d'activation */
	BOOLGADGET,		/* Type de gadget */
	(APTR)&HEXImage,	/* Ptr a une image ou bordure */
	(APTR)&DECImage,	/* Ptr a l'image alterne */
	NULL,			/* IntuiText */
	NULL,			/* exclusion mutuelle */
	NULL,			/* structure SpecialInfo */
	Mode_ID,		/* Identification du gadget */
	NULL			/* User data */
};

/*************************************************************************
**************************************************************************
**
**  L'image de la calculatrice.
**
*/


UWORD CalcImage[] =
{
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,
	0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,
	0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x5555,0x5555,0x5555,
	0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,
	0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0xA800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0A80,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x41FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x941F,0xFFE7,0xFFF9,
	0xFFFF,0x9FFE,0x7FF9,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0x81FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x881F,
	0x03E7,0xFFF9,0xFFFF,0x9FFE,0x7FF8,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x41FF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0x941E,0x31E7,0xFFF9,0xFFFF,0x9C0E,0x7039,0x4000,
	0x0000,0x0000,0x0000,0x0300,0x0000,0x0000,0x0002,0x81FC,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x003F,0x881E,0x79E7,0x00F9,0xC003,0x98CE,
	0x7318,0x8000,0x0000,0x0000,0x0000,0x0780,0x0000,0x0000,
	0x0001,0x41FC,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x003F,0x941C,0x78E7,0x3C79,
	0xCFF3,0x999E,0x7999,0x4000,0x0000,0x0000,0x0000,0x0780,
	0x0000,0x0000,0x0002,0x81FC,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x003F,0x881C,
	0xCCE7,0x0679,0xC003,0x999E,0x7998,0x8000,0x0000,0x0000,
	0x0000,0x0CC0,0x0000,0x0000,0x0001,0x41FC,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x003F,0x9418,0xFC66,0x1E79,0xCFF3,0x999E,0x7999,0x4000,
	0x0000,0x0000,0x0000,0x0FC0,0x0000,0x0000,0x0002,0x81FC,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x003F,0x8819,0x8666,0x6639,0xC003,0x98CE,
	0x7318,0x8000,0x0000,0x0000,0x0000,0x1860,0x0000,0x0000,
	0x0001,0x41FC,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x003F,0x9419,0x8666,0x3B39,
	0xFFFF,0x9C0E,0x7039,0x4000,0x0000,0x0000,0x0000,0x1860,
	0x0000,0x0000,0x0002,0x81FC,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x003F,0x8818,
	0x0067,0x0039,0xFFFF,0x9FFE,0x7FF8,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x41FC,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x003F,0x941F,0xFFE7,0xFFF9,0xFFFF,0x9FFE,0x7FF9,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0x81FC,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x003F,0x8800,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x41FC,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x003F,0x941F,0xFFE7,0xFFF9,
	0xFFFF,0x9FFF,0xFFF9,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0x81FC,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x003F,0x881C,
	0x00E6,0x03F9,0xFFFF,0x9FFF,0xFFF8,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x41FC,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x003F,0x941C,0xFC66,0x73F9,0xF81F,0x9F83,0xFFF9,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0x81FC,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x003F,0x881C,0x6666,0x3079,0xF99F,0x9F13,
	0xFFF8,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x41FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x941E,0x6667,0x3639,
	0xF99F,0x9E30,0x0079,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0x81FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x881E,
	0x7C67,0x3B39,0xF99F,0x9E7F,0xFE78,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x41FF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0x941E,0x6667,0x3339,0xF99F,0x9E30,0x0079,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0x8000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x081C,0x6667,0x3339,0xF99F,0x9F13,
	0xFFF8,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x4000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x541C,0xFC67,0x1E39,
	0xF81F,0x9F83,0xFFF9,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,
	0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xA81C,
	0x00E7,0x8079,0xFFFF,0x9FFF,0xFFF8,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x5555,0x5555,0x5555,
	0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,
	0x5555,0x541F,0xFFE7,0xFFF9,0xFFFF,0x9FFF,0xFFF9,0x4000,
	0x0000,0x01F8,0x0000,0x0000,0x0000,0x7800,0x0002,0xA800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x00AA,0xAAAA,0xAAAA,0xA800,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x8000,0x0000,0x00CC,0x0000,0x0000,0x0000,0xCC00,
	0x0001,0x4000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0055,0x5555,0x5555,0x541F,0xFFE7,0xFFF9,
	0xFFFF,0x9FFE,0x7FF9,0x4000,0x0000,0x00CC,0x0000,0x0000,
	0x0001,0x8000,0x0002,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x00AA,0xAAAA,0xAAAA,0xA81E,
	0x01E7,0xFFF9,0xFFFF,0x9FFE,0x7FF8,0x8000,0x0000,0x00F8,
	0x0000,0x0000,0x0001,0x8000,0x0001,0x4000,0xF000,0x3800,
	0x0F0F,0xE000,0x0000,0x0000,0x0000,0x0000,0x0055,0x5555,
	0x5555,0x541C,0x78E7,0xFFF9,0xF81F,0x9F1E,0x78F9,0x4000,
	0x0000,0x00CC,0x0000,0x0000,0x0001,0x8000,0x0002,0x8001,
	0x9800,0x1800,0x0606,0x6000,0x0000,0x0000,0x0000,0x0000,
	0x00AA,0xAAAA,0xAAAA,0xA818,0xCCE7,0x8079,0xE3C7,0x9E4E,
	0x7278,0x8000,0x0000,0x00CC,0x0000,0x0000,0x0000,0xCC00,
	0x0001,0x4003,0x00F0,0xD8F0,0x0606,0x000F,0xC000,0x0000,
	0x0000,0x0000,0x0055,0x5555,0x5555,0x5419,0x80E7,0x1E39,
	0xCFF3,0x9CCE,0x7339,0x4000,0x0000,0x01F8,0x0000,0x0000,
	0x0000,0x7800,0x0002,0x8003,0x0199,0xB998,0x0607,0x8000,
	0x0000,0x0000,0x0000,0x0000,0x00AA,0xAAAA,0xAAAA,0xA819,
	0x9FE7,0x3339,0xCFF3,0x999E,0x7998,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x4003,0x0199,0x99F8,
	0x0626,0x0000,0x0000,0x0000,0x0000,0x0000,0x0055,0x5555,
	0x5555,0x5419,0x80E7,0x3039,0xCFF3,0x9CCE,0x7339,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0x8001,
	0x9999,0x9980,0x0666,0x000F,0xC000,0x0000,0x0000,0x0000,
	0x00AA,0xAAAA,0xAAAA,0xA818,0xCCE7,0x3339,0xE3C7,0x9E4E,
	0x7278,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x4000,0xF0F0,0xECF0,0x0FEF,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0055,0x5555,0x5555,0x541C,0x78E7,0x1E39,
	0xF81F,0x9F1E,0x78F9,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x00AA,0xAAAA,0xAAAA,0xA81E,
	0x01E7,0x8079,0xFFFF,0x9FFE,0x7FF8,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x4000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0055,0x5555,
	0x5555,0x541F,0xFFE7,0xFFF9,0xFFFF,0x9FFE,0x7FF9,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0002,0x8000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x00AA,0xAAAA,0xAAAA,0xA800,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0x4000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0555,0x5555,0x5555,0x5400,0x0000,0x0000,
	0x0000,0x0000,0x0015,0x4000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0002,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,
	0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,
	0xAAAA,0xAAAA,0xAAAA,0xAAAA,0xAAAA,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0001,0x5555,0x5555,0x5555,
	0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,
	0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x5555,0x4000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFCF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xE814,0x0A05,
	0x0281,0x40A0,0x5028,0x140A,0x05CF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xD008,0x0402,0x0100,0x8040,0x2010,0x0804,0x02CF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xE814,0x0A05,0x0281,0x40A0,0x5028,0x140A,
	0x05CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xF000,0xC422,0x1108,0x8443,0xFFFE,
	0x8844,0x2211,0x08CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xC241,0x2090,
	0x48FF,0x0007,0xFC82,0x4120,0x90CF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xC180,0xC060,0x3FC0,0x0000,0x1F81,0x80C0,0x60CF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xCFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xC180,0xC060,0x7C00,0x0000,0x01E1,0x80C0,
	0x60CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x87FF,0xFFFF,
	0xFFFF,0xFF3F,0xFCFF,0xF000,0xC241,0x2091,0xF000,0x0000,
	0x007A,0x4120,0x90CF,0xFFFF,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x00FF,0xFFFF,
	0x87FF,0xC3FF,0xF00F,0xFE7F,0xFE7F,0xF000,0xC422,0x110F,
	0xC000,0x0000,0x001E,0x2211,0x08CF,0xFFFF,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x00FF,0xFFFF,0x33FF,0xF9FF,0xFFFF,0xFE7F,0xFE7F,0xF000,
	0xE814,0x0A1F,0x0000,0x0000,0x0007,0x140A,0x05CF,0xFFFF,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x00FF,0xFFFF,0x03FF,0xE1FF,0xF00F,0xFE7F,
	0xFE7F,0xF000,0xD008,0x043E,0x0000,0x0000,0x0003,0x8804,
	0x02CF,0xFFFF,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x00FF,0xFFFE,0x79FF,0x99FF,
	0xFFFF,0xFF3F,0xFCFF,0xF000,0xE814,0x0A7C,0x0000,0x0000,
	0x0001,0xD40A,0x05CF,0xFFFF,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x00FF,0xFFFE,
	0x79FF,0xC4FF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xC422,0x11F8,
	0x0000,0x0000,0x0000,0xE211,0x08CF,0xFFFF,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x00FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xC241,0x21F0,0x0000,0x0000,0x0000,0x7120,0x90CF,0xFFFF,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x00FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xC180,0xC3F3,0xFFFE,0x0001,0xFFFF,0x70C0,
	0x60CF,0xFFFF,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x00FF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xF000,0xC180,0xC3FF,0x0007,0xF87F,
	0x8003,0xFCC0,0x60CF,0xFFFF,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x00FF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xC241,0x2FF0,
	0x0000,0x1FE0,0x0000,0x7FE0,0x90CF,0xFFFF,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x00FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xC422,0x7C70,0x0000,0x1FE0,0x0000,0x70F1,0x08CF,0xFFFF,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x00FF,0xFFFF,0x03FF,0x8FFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xE815,0xF038,0x0000,0x7878,0x0000,0xE03E,
	0x05CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x99FF,0xCFFF,
	0xFE7F,0xFFEF,0xFFFF,0xF000,0xD00F,0xC01C,0x0001,0xE01E,
	0x0001,0xC00F,0x02CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0x99FF,0xC9FF,0xFE7F,0xFFCF,0xFFFF,0xF000,0xE81F,0x000E,
	0x0003,0x8007,0x0003,0x8003,0x85CF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0x83FF,0xC4FF,0xFE7F,0xFF80,0x01FF,0xF000,
	0xC43E,0x0007,0x0007,0x0003,0x8007,0x0001,0xC8CF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x99FF,0xCCFF,0xFE7F,0xFFCF,
	0xFFFF,0xF000,0xC27C,0x0003,0xC00E,0x0001,0xC01E,0x0000,
	0xF0CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0x99FF,0xCCFF,
	0xFE7F,0xFFEF,0xFFFF,0xF000,0xC1F8,0x0000,0xF01C,0x0000,
	0xE078,0x0000,0x70CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0x03FF,0xE1FF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xC1F0,0x0000,
	0x3C38,0x0000,0x71E0,0x0000,0x38CF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xC3F0,0x0000,0x0FF8,0x0000,0x7F80,0x0000,0x38CF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xC7F0,0x0000,0x00FF,0x0007,0xF800,0x0000,
	0x38CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xF000,0xEBF0,0x0000,0x003B,0xFFFE,
	0x7000,0x0000,0x3DCF,0xFE00,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xD3F0,0x0000,
	0x0038,0x0000,0x7000,0x0000,0x3ACF,0xFE03,0xFC00,0xFE00,
	0x3FFF,0xF800,0x0000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xEBF8,0x0000,0x001C,0x0000,0xE000,0x0000,0x75CF,0xFE07,
	0x0E00,0xC600,0x30F0,0x1800,0x0000,0x0000,0x0000,0x0000,
	0x03FF,0xFFFF,0xFFFF,0xFFFF,0x87FF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xC5FC,0x0000,0x000E,0x0001,0xC000,0x0000,
	0xE8CF,0xFE0E,0x67FF,0xE7FC,0x39F9,0x983F,0xF000,0x0000,
	0x0000,0x0000,0x03FF,0xFFFF,0xFFFF,0xFFFF,0x33FF,0xFFFF,
	0xFC3F,0xFFBF,0xFDFF,0xF000,0xC2FE,0x0000,0x0007,0x0003,
	0x8000,0x0001,0xD0CF,0xFE0C,0xFF0F,0x270E,0x1999,0xF830,
	0x3000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,0xFFFF,0xFFFE,
	0x7FFF,0xE1FF,0xF00F,0xFF3F,0xFCFF,0xF000,0xC1FF,0x0000,
	0x0003,0x8007,0x0000,0x0003,0xE0CF,0xFE0C,0xC666,0x4666,
	0x19F8,0x603F,0xF000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,
	0xFFFF,0xFFFE,0x7FFF,0xCCFF,0xF00F,0xFE7F,0xFE7F,0xF000,
	0xC1BF,0xC000,0x0001,0xE01E,0x0000,0x000F,0x60CF,0xFE0C,
	0xFE66,0x6606,0x19D9,0xE03F,0xF000,0x0000,0x0000,0x0000,
	0x03FF,0xFFFF,0xFFFF,0xFFFE,0x7FFF,0xCFFF,0xF00F,0xFF3F,
	0xFCFF,0xF000,0xC25F,0xF000,0x0000,0x7878,0x0000,0x003C,
	0x90CF,0xFE0E,0x6666,0x667E,0x3999,0xC030,0x3000,0x0000,
	0x0000,0x0000,0x03FF,0xFFFF,0xFFFF,0xFFFF,0x33FF,0xCCFF,
	0xFC3F,0xFFBF,0xFDFF,0xF000,0xC427,0xFC00,0x0000,0x1FE0,
	0x0000,0x00F1,0x08CF,0xFE07,0x0F0F,0x130C,0x3010,0xC03F,
	0xF000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,0xFFFF,0xFFFF,
	0x87FF,0xE1FF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xE815,0xFFC0,
	0x0000,0x1FE0,0x0000,0x0FCA,0x05CF,0xFE03,0xFFFF,0xFFFC,
	0x3FFF,0xC000,0x0000,0x0000,0x0000,0x0000,0x03FF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xD008,0x7FFF,0x0007,0xFFFF,0x8003,0xFE04,0x02CF,0xFE00,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x03FF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xE814,0x0FFF,0xFFFF,0xC3FF,0xFFFF,0xF40A,
	0x05CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xF000,0xC422,0x111F,0xFFF2,0x211F,
	0xFFFC,0x2211,0x08CF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,0xC241,0x2090,
	0x4824,0x1209,0x0482,0x4120,0x90CF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF000,
	0xC180,0xC060,0x3018,0x0C06,0x0301,0x80C0,0x60CF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xF000,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFCF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
	0xFFFF,0xFFFF,0xFFFF,0xF000
};

struct Image Dessin =
{
	0,10,			/* Decalage XY du coin superieur gauche du contenant */
	404,45,			/* Largeur et hauteur */
	2,			/* Nb de bitplanes */
	CalcImage,		/* Ptr a l'information graphique */
	0x0003,0x0000,		/* PlanePick et PlaneOnOff */
	NULL			/* Structure Image suivante */
};

/*************************************************************************
**************************************************************************
**
**  Informations pour l'ouverture de la fenetre.
**
*/


struct NewWindow FenetreData =
{
	144,45,			/* Origine XY de la fenetre */
	404,55,			/* Ses largeur et hauteur */
	1,2,			/* Couleurs du cadre (detail and block pens) */
	GADGETDOWN|GADGETUP|CLOSEWINDOW, /* Flags IDCMP */
	WINDOWDRAG|WINDOWDEPTH|WINDOWCLOSE|ACTIVATE|RMBTRAP, /* Flags de la fenetre */
	&ModeGadg,		/* Ptr au premier gadget */
	NULL,			/* Crochet pour les menus (CHECKMARK) */
	(UBYTE *)TITRE,		/* Titre de la fenetre */
	NULL,			/* Ptr a l'ecran ou on apparait (ici: WB) */
	NULL,			/* Notre propre bitmap (on en a pas) */
	0,0,			/* Largeur et hauteur min (pas pertinent) */
	0,0,			/* Largeur et hauteur max (pas pertinent) */
	WBENCHSCREEN		/* Type d'ecran de destination */
};

/************************************************************************/
